@@ -29,12 +29,9 @@ Implementation Notes
 # compatible classes so we won't bother with some lints until then.
 # pylint: disable=missing-docstring,invalid-name,too-many-public-methods,no-name-in-module
 
+import struct
 import time
 
-try:
-    import struct
-except ImportError:
-    import ustruct as struct
 try:
     from micropython import const
 except ImportError:
@@ -242,7 +239,7 @@ class Seesaw:
         self.read(_GPIO_BASE, _GPIO_INTFLAG, buf, delay=delay)
         return struct.unpack(">I", buf)[0]
 
-    def analog_read(self, pin):
+    def analog_read(self, pin, delay=0.008):
         """Read the value of an analog pin by number"""
         buf = bytearray(2)
         if pin not in self.pin_mapping.analog_pins:
@@ -253,13 +250,8 @@ class Seesaw:
         elif self.chip_id == _SAMD09_HW_ID_CODE:
             offset = self.pin_mapping.analog_pins.index(pin)
 
-        self.read(
-            _ADC_BASE,
-            _ADC_CHANNEL_OFFSET + offset,
-            buf,
-        )
+        self.read(_ADC_BASE, _ADC_CHANNEL_OFFSET + offset, buf, delay)
         ret = struct.unpack(">H", buf)[0]
-        time.sleep(0.001)
         return ret
 
     def touch_read(self, pin):
